@@ -1,20 +1,20 @@
 use crate::injector::Injector;
 
-pub trait Injection {
-    fn build_injection(injector: &mut Injector) -> Self;
+pub trait Injection where Self: Sized {
+    fn build_injection(injector: &mut Injector) -> Result<Self, crate::DiError>;
 }
 
 impl<T> Injection for Box<T> where T: Injection {
-    fn build_injection(injector: &mut Injector) -> Self {
-        Box::new(T::build_injection(injector))
+    fn build_injection(injector: &mut Injector) -> Result<Self, crate::DiError> {
+        Ok(Box::new(T::build_injection(injector)?))
     }
 }
 
 macro_rules! injection {
     ($type:ty, $build_call:expr) => {
         impl Injection for $type {
-            fn build_injection(_: &mut Injector) -> Self {
-                $build_call
+            fn build_injection(_: &mut Injector) -> Result<Self, crate::DiError> {
+                Ok($build_call)
             }
         }
     }
